summary refs log tree commit diff
path: root/pkgs/top-level/php-packages.nix
diff options
context:
space:
mode:
authorElis Hirwing <elis@hirwing.se>2020-03-15 19:34:28 +0100
committerElis Hirwing <elis@hirwing.se>2020-03-15 19:34:28 +0100
commit1f5af3c60608b69bc62f9789850e8280a4d53034 (patch)
treeaf6d79caccab6240cb572eebea250601a07295b5 /pkgs/top-level/php-packages.nix
parentc61d907f812abb0f3de738cbaa4a37fc7f96cbc9 (diff)
downloadnixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.tar
nixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.tar.gz
nixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.tar.bz2
nixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.tar.lz
nixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.tar.xz
nixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.tar.zst
nixpkgs-1f5af3c60608b69bc62f9789850e8280a4d53034.zip
phpPackages.exts: Mark if extensions are zend extensions or not
Diffstat (limited to 'pkgs/top-level/php-packages.nix')
-rw-r--r--pkgs/top-level/php-packages.nix8
1 files changed, 5 insertions, 3 deletions
diff --git a/pkgs/top-level/php-packages.nix b/pkgs/top-level/php-packages.nix
index a43e44417d9..cc830fa3498 100644
--- a/pkgs/top-level/php-packages.nix
+++ b/pkgs/top-level/php-packages.nix
@@ -704,11 +704,13 @@ let
     # Name passed is the name of the extension and is automatically used
     # to add the configureFlag "--enable-${name}", which can be overriden.
     #
     # Build inputs is used for extra deps that may be needed.
     mkExtension = {
       name
       , configureFlags ? [ "--enable-${name}" ]
       , buildInputs ? []
+      , zendExtension ? false
       , ...
     }: stdenv.mkDerivation {
       pname = "php-ext-${name}";
@@ -718,7 +720,7 @@ let
 
       enableParallelBuilding = true;
       nativeBuildInputs = [ php autoconf pkgconfig re2c ];
-      inherit configureFlags buildInputs;
+      inherit configureFlags buildInputs zendExtension;
 
       preConfigure = "phpize";
 
@@ -811,7 +813,7 @@ let
       { name = "mysqli"; configureFlags = [ "--with-mysqli=mysqlnd" "--with-mysql-sock=/run/mysqld/mysqld.sock" ]; }
       # oci8 (7.4, 7.3, 7.2)
       # odbc (7.4, 7.3, 7.2)
-      { name = "opcache"; buildInputs = [ pcre' ]; }
+      { name = "opcache"; buildInputs = [ pcre' ]; zendExtension = true; }
       { name = "pcntl"; }
       { name = "pdo"; }
       { name = "pdo_dblib";
@@ -704,11 +704,13 @@ let
     # to add the configureFlag "--enable-${name}", which can be overriden.
     #
-    # Build inputs is used for extra deps that may be needed.
+    # Build inputs is used for extra deps that may be needed. And zendExtension
+    # will mark the extension as a zend extension or not.
     mkExtension = {
       name